Documentation
¶
Overview ¶
This package has the automatically generated typed clients.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type InternalV1beta1Client ¶
type InternalV1beta1Client struct {
// contains filtered or unexported fields
}
InternalV1beta1Client is used to interact with features provided by the internal.events.cloud.google.com group.
func New ¶
func New(c rest.Interface) *InternalV1beta1Client
New creates a new InternalV1beta1Client for the given RESTClient.
func NewForConfig ¶
func NewForConfig(c *rest.Config) (*InternalV1beta1Client, error)
NewForConfig creates a new InternalV1beta1Client for the given config.
func NewForConfigOrDie ¶
func NewForConfigOrDie(c *rest.Config) *InternalV1beta1Client
NewForConfigOrDie creates a new InternalV1beta1Client for the given config and panics if there is an error in the config.
func (*InternalV1beta1Client) PullSubscriptions ¶
func (c *InternalV1beta1Client) PullSubscriptions(namespace string) PullSubscriptionInterface
func (*InternalV1beta1Client) RESTClient ¶
func (c *InternalV1beta1Client) RESTClient() rest.Interface
RESTClient returns a RESTClient that is used to communicate with API server by this client implementation.
func (*InternalV1beta1Client) Topics ¶
func (c *InternalV1beta1Client) Topics(namespace string) TopicInterface
type InternalV1beta1Interface ¶
type InternalV1beta1Interface interface {
RESTClient() rest.Interface
PullSubscriptionsGetter
TopicsGetter
}
type PullSubscriptionExpansion ¶
type PullSubscriptionExpansion interface{}
type PullSubscriptionInterface ¶
type PullSubscriptionInterface interface {
Create(ctx context.Context, pullSubscription *v1beta1.PullSubscription, opts v1.CreateOptions) (*v1beta1.PullSubscription, error)
Update(ctx context.Context, pullSubscription *v1beta1.PullSubscription, opts v1.UpdateOptions) (*v1beta1.PullSubscription, error)
UpdateStatus(ctx context.Context, pullSubscription *v1beta1.PullSubscription, opts v1.UpdateOptions) (*v1beta1.PullSubscription, error)
Delete(ctx context.Context, name string, opts v1.DeleteOptions) error
DeleteCollection(ctx context.Context, opts v1.DeleteOptions, listOpts v1.ListOptions) error
Get(ctx context.Context, name string, opts v1.GetOptions) (*v1beta1.PullSubscription, error)
List(ctx context.Context, opts v1.ListOptions) (*v1beta1.PullSubscriptionList, error)
Watch(ctx context.Context, opts v1.ListOptions) (watch.Interface, error)
Patch(ctx context.Context, name string, pt types.PatchType, data []byte, opts v1.PatchOptions, subresources ...string) (result *v1beta1.PullSubscription, err error)
PullSubscriptionExpansion
}
PullSubscriptionInterface has methods to work with PullSubscription resources.
type PullSubscriptionsGetter ¶
type PullSubscriptionsGetter interface {
PullSubscriptions(namespace string) PullSubscriptionInterface
}
PullSubscriptionsGetter has a method to return a PullSubscriptionInterface. A group's client should implement this interface.
type TopicExpansion ¶
type TopicExpansion interface{}
type TopicInterface ¶
type TopicInterface interface {
Create(ctx context.Context, topic *v1beta1.Topic, opts v1.CreateOptions) (*v1beta1.Topic, error)
Update(ctx context.Context, topic *v1beta1.Topic, opts v1.UpdateOptions) (*v1beta1.Topic, error)
UpdateStatus(ctx context.Context, topic *v1beta1.Topic, opts v1.UpdateOptions) (*v1beta1.Topic, error)
Delete(ctx context.Context, name string, opts v1.DeleteOptions) error
DeleteCollection(ctx context.Context, opts v1.DeleteOptions, listOpts v1.ListOptions) error
Get(ctx context.Context, name string, opts v1.GetOptions) (*v1beta1.Topic, error)
List(ctx context.Context, opts v1.ListOptions) (*v1beta1.TopicList, error)
Watch(ctx context.Context, opts v1.ListOptions) (watch.Interface, error)
Patch(ctx context.Context, name string, pt types.PatchType, data []byte, opts v1.PatchOptions, subresources ...string) (result *v1beta1.Topic, err error)
TopicExpansion
}
TopicInterface has methods to work with Topic resources.
type TopicsGetter ¶
type TopicsGetter interface {
Topics(namespace string) TopicInterface
}
TopicsGetter has a method to return a TopicInterface. A group's client should implement this interface.