Documentation
¶
Overview ¶
This package has the automatically generated typed clients.
Index ¶
- type EventPoliciesGetter
- type EventPolicyBindingExpansion
- type EventPolicyBindingInterface
- type EventPolicyBindingsGetter
- type EventPolicyExpansion
- type EventPolicyInterface
- type HTTPPoliciesGetter
- type HTTPPolicyBindingExpansion
- type HTTPPolicyBindingInterface
- type HTTPPolicyBindingsGetter
- type HTTPPolicyExpansion
- type HTTPPolicyInterface
- type PolicyV1alpha1Client
- func (c *PolicyV1alpha1Client) EventPolicies(namespace string) EventPolicyInterface
- func (c *PolicyV1alpha1Client) EventPolicyBindings(namespace string) EventPolicyBindingInterface
- func (c *PolicyV1alpha1Client) HTTPPolicies(namespace string) HTTPPolicyInterface
- func (c *PolicyV1alpha1Client) HTTPPolicyBindings(namespace string) HTTPPolicyBindingInterface
- func (c *PolicyV1alpha1Client) RESTClient() rest.Interface
- type PolicyV1alpha1Interface
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type EventPoliciesGetter ¶
type EventPoliciesGetter interface {
EventPolicies(namespace string) EventPolicyInterface
}
EventPoliciesGetter has a method to return a EventPolicyInterface. A group's client should implement this interface.
type EventPolicyBindingExpansion ¶
type EventPolicyBindingExpansion interface{}
type EventPolicyBindingInterface ¶
type EventPolicyBindingInterface interface {
Create(*v1alpha1.EventPolicyBinding) (*v1alpha1.EventPolicyBinding, error)
Update(*v1alpha1.EventPolicyBinding) (*v1alpha1.EventPolicyBinding, error)
UpdateStatus(*v1alpha1.EventPolicyBinding) (*v1alpha1.EventPolicyBinding, error)
Delete(name string, options *v1.DeleteOptions) error
DeleteCollection(options *v1.DeleteOptions, listOptions v1.ListOptions) error
Get(name string, options v1.GetOptions) (*v1alpha1.EventPolicyBinding, error)
List(opts v1.ListOptions) (*v1alpha1.EventPolicyBindingList, error)
Watch(opts v1.ListOptions) (watch.Interface, error)
Patch(name string, pt types.PatchType, data []byte, subresources ...string) (result *v1alpha1.EventPolicyBinding, err error)
EventPolicyBindingExpansion
}
EventPolicyBindingInterface has methods to work with EventPolicyBinding resources.
type EventPolicyBindingsGetter ¶
type EventPolicyBindingsGetter interface {
EventPolicyBindings(namespace string) EventPolicyBindingInterface
}
EventPolicyBindingsGetter has a method to return a EventPolicyBindingInterface. A group's client should implement this interface.
type EventPolicyExpansion ¶
type EventPolicyExpansion interface{}
type EventPolicyInterface ¶
type EventPolicyInterface interface {
Create(*v1alpha1.EventPolicy) (*v1alpha1.EventPolicy, error)
Update(*v1alpha1.EventPolicy) (*v1alpha1.EventPolicy, error)
Delete(name string, options *v1.DeleteOptions) error
DeleteCollection(options *v1.DeleteOptions, listOptions v1.ListOptions) error
Get(name string, options v1.GetOptions) (*v1alpha1.EventPolicy, error)
List(opts v1.ListOptions) (*v1alpha1.EventPolicyList, error)
Watch(opts v1.ListOptions) (watch.Interface, error)
Patch(name string, pt types.PatchType, data []byte, subresources ...string) (result *v1alpha1.EventPolicy, err error)
EventPolicyExpansion
}
EventPolicyInterface has methods to work with EventPolicy resources.
type HTTPPoliciesGetter ¶
type HTTPPoliciesGetter interface {
HTTPPolicies(namespace string) HTTPPolicyInterface
}
HTTPPoliciesGetter has a method to return a HTTPPolicyInterface. A group's client should implement this interface.
type HTTPPolicyBindingExpansion ¶
type HTTPPolicyBindingExpansion interface{}
type HTTPPolicyBindingInterface ¶
type HTTPPolicyBindingInterface interface {
Create(*v1alpha1.HTTPPolicyBinding) (*v1alpha1.HTTPPolicyBinding, error)
Update(*v1alpha1.HTTPPolicyBinding) (*v1alpha1.HTTPPolicyBinding, error)
UpdateStatus(*v1alpha1.HTTPPolicyBinding) (*v1alpha1.HTTPPolicyBinding, error)
Delete(name string, options *v1.DeleteOptions) error
DeleteCollection(options *v1.DeleteOptions, listOptions v1.ListOptions) error
Get(name string, options v1.GetOptions) (*v1alpha1.HTTPPolicyBinding, error)
List(opts v1.ListOptions) (*v1alpha1.HTTPPolicyBindingList, error)
Watch(opts v1.ListOptions) (watch.Interface, error)
Patch(name string, pt types.PatchType, data []byte, subresources ...string) (result *v1alpha1.HTTPPolicyBinding, err error)
HTTPPolicyBindingExpansion
}
HTTPPolicyBindingInterface has methods to work with HTTPPolicyBinding resources.
type HTTPPolicyBindingsGetter ¶
type HTTPPolicyBindingsGetter interface {
HTTPPolicyBindings(namespace string) HTTPPolicyBindingInterface
}
HTTPPolicyBindingsGetter has a method to return a HTTPPolicyBindingInterface. A group's client should implement this interface.
type HTTPPolicyExpansion ¶
type HTTPPolicyExpansion interface{}
type HTTPPolicyInterface ¶
type HTTPPolicyInterface interface {
Create(*v1alpha1.HTTPPolicy) (*v1alpha1.HTTPPolicy, error)
Update(*v1alpha1.HTTPPolicy) (*v1alpha1.HTTPPolicy, error)
Delete(name string, options *v1.DeleteOptions) error
DeleteCollection(options *v1.DeleteOptions, listOptions v1.ListOptions) error
Get(name string, options v1.GetOptions) (*v1alpha1.HTTPPolicy, error)
List(opts v1.ListOptions) (*v1alpha1.HTTPPolicyList, error)
Watch(opts v1.ListOptions) (watch.Interface, error)
Patch(name string, pt types.PatchType, data []byte, subresources ...string) (result *v1alpha1.HTTPPolicy, err error)
HTTPPolicyExpansion
}
HTTPPolicyInterface has methods to work with HTTPPolicy resources.
type PolicyV1alpha1Client ¶
type PolicyV1alpha1Client struct {
// contains filtered or unexported fields
}
PolicyV1alpha1Client is used to interact with features provided by the policy.run.cloud.google.com group.
func New ¶
func New(c rest.Interface) *PolicyV1alpha1Client
New creates a new PolicyV1alpha1Client for the given RESTClient.
func NewForConfig ¶
func NewForConfig(c *rest.Config) (*PolicyV1alpha1Client, error)
NewForConfig creates a new PolicyV1alpha1Client for the given config.
func NewForConfigOrDie ¶
func NewForConfigOrDie(c *rest.Config) *PolicyV1alpha1Client
NewForConfigOrDie creates a new PolicyV1alpha1Client for the given config and panics if there is an error in the config.
func (*PolicyV1alpha1Client) EventPolicies ¶
func (c *PolicyV1alpha1Client) EventPolicies(namespace string) EventPolicyInterface
func (*PolicyV1alpha1Client) EventPolicyBindings ¶
func (c *PolicyV1alpha1Client) EventPolicyBindings(namespace string) EventPolicyBindingInterface
func (*PolicyV1alpha1Client) HTTPPolicies ¶
func (c *PolicyV1alpha1Client) HTTPPolicies(namespace string) HTTPPolicyInterface
func (*PolicyV1alpha1Client) HTTPPolicyBindings ¶
func (c *PolicyV1alpha1Client) HTTPPolicyBindings(namespace string) HTTPPolicyBindingInterface
func (*PolicyV1alpha1Client) RESTClient ¶
func (c *PolicyV1alpha1Client) RESTClient() rest.Interface
RESTClient returns a RESTClient that is used to communicate with API server by this client implementation.
type PolicyV1alpha1Interface ¶
type PolicyV1alpha1Interface interface {
RESTClient() rest.Interface
EventPoliciesGetter
EventPolicyBindingsGetter
HTTPPoliciesGetter
HTTPPolicyBindingsGetter
}