Documentation
¶
Overview ¶
This package has the automatically generated typed clients.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type PubsubV1alpha1Client ¶
type PubsubV1alpha1Client struct {
// contains filtered or unexported fields
}
PubsubV1alpha1Client is used to interact with features provided by the pubsub.cloud.google.com group.
func New ¶
func New(c rest.Interface) *PubsubV1alpha1Client
New creates a new PubsubV1alpha1Client for the given RESTClient.
func NewForConfig ¶
func NewForConfig(c *rest.Config) (*PubsubV1alpha1Client, error)
NewForConfig creates a new PubsubV1alpha1Client for the given config.
func NewForConfigOrDie ¶
func NewForConfigOrDie(c *rest.Config) *PubsubV1alpha1Client
NewForConfigOrDie creates a new PubsubV1alpha1Client for the given config and panics if there is an error in the config.
func (*PubsubV1alpha1Client) PullSubscriptions ¶
func (c *PubsubV1alpha1Client) PullSubscriptions(namespace string) PullSubscriptionInterface
func (*PubsubV1alpha1Client) RESTClient ¶
func (c *PubsubV1alpha1Client) RESTClient() rest.Interface
RESTClient returns a RESTClient that is used to communicate with API server by this client implementation.
func (*PubsubV1alpha1Client) Topics ¶
func (c *PubsubV1alpha1Client) Topics(namespace string) TopicInterface
type PubsubV1alpha1Interface ¶
type PubsubV1alpha1Interface interface {
RESTClient() rest.Interface
PullSubscriptionsGetter
TopicsGetter
}
type PullSubscriptionExpansion ¶
type PullSubscriptionExpansion interface{}
type PullSubscriptionInterface ¶
type PullSubscriptionInterface interface {
Create(*v1alpha1.PullSubscription) (*v1alpha1.PullSubscription, error)
Update(*v1alpha1.PullSubscription) (*v1alpha1.PullSubscription, error)
UpdateStatus(*v1alpha1.PullSubscription) (*v1alpha1.PullSubscription, error)
Delete(name string, options *v1.DeleteOptions) error
DeleteCollection(options *v1.DeleteOptions, listOptions v1.ListOptions) error
Get(name string, options v1.GetOptions) (*v1alpha1.PullSubscription, error)
List(opts v1.ListOptions) (*v1alpha1.PullSubscriptionList, error)
Watch(opts v1.ListOptions) (watch.Interface, error)
Patch(name string, pt types.PatchType, data []byte, subresources ...string) (result *v1alpha1.PullSubscription, err error)
PullSubscriptionExpansion
}
PullSubscriptionInterface has methods to work with PullSubscription resources.
type PullSubscriptionsGetter ¶
type PullSubscriptionsGetter interface {
PullSubscriptions(namespace string) PullSubscriptionInterface
}
PullSubscriptionsGetter has a method to return a PullSubscriptionInterface. A group's client should implement this interface.
type TopicExpansion ¶
type TopicExpansion interface{}
type TopicInterface ¶
type TopicInterface interface {
Create(*v1alpha1.Topic) (*v1alpha1.Topic, error)
Update(*v1alpha1.Topic) (*v1alpha1.Topic, error)
UpdateStatus(*v1alpha1.Topic) (*v1alpha1.Topic, error)
Delete(name string, options *v1.DeleteOptions) error
DeleteCollection(options *v1.DeleteOptions, listOptions v1.ListOptions) error
Get(name string, options v1.GetOptions) (*v1alpha1.Topic, error)
List(opts v1.ListOptions) (*v1alpha1.TopicList, error)
Watch(opts v1.ListOptions) (watch.Interface, error)
Patch(name string, pt types.PatchType, data []byte, subresources ...string) (result *v1alpha1.Topic, err error)
TopicExpansion
}
TopicInterface has methods to work with Topic resources.
type TopicsGetter ¶
type TopicsGetter interface {
Topics(namespace string) TopicInterface
}
TopicsGetter has a method to return a TopicInterface. A group's client should implement this interface.