Documentation
¶
Index ¶
- func NewBrokerCellInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, ...) cache.SharedIndexInformer
- func NewFilteredBrokerCellInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, ...) cache.SharedIndexInformer
- type BrokerCellInformer
- type Interface
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewBrokerCellInformer ¶
func NewBrokerCellInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, indexers cache.Indexers) cache.SharedIndexInformer
NewBrokerCellInformer constructs a new informer for BrokerCell type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
func NewFilteredBrokerCellInformer ¶
func NewFilteredBrokerCellInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, indexers cache.Indexers, tweakListOptions internalinterfaces.TweakListOptionsFunc) cache.SharedIndexInformer
NewFilteredBrokerCellInformer constructs a new informer for BrokerCell type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
Types ¶
type BrokerCellInformer ¶
type BrokerCellInformer interface {
Informer() cache.SharedIndexInformer
Lister() v1alpha1.BrokerCellLister
}
BrokerCellInformer provides access to a shared informer and lister for BrokerCells.
type Interface ¶
type Interface interface {
// BrokerCells returns a BrokerCellInformer.
BrokerCells() BrokerCellInformer
}
Interface provides access to all the informers in this group version.
func New ¶
func New(f internalinterfaces.SharedInformerFactory, namespace string, tweakListOptions internalinterfaces.TweakListOptionsFunc) Interface
New returns a new Interface.