Documentation
¶
Index ¶
- func NewChannelInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, ...) cache.SharedIndexInformer
- func NewDecoratorInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, ...) cache.SharedIndexInformer
- func NewFilteredChannelInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, ...) cache.SharedIndexInformer
- func NewFilteredDecoratorInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, ...) cache.SharedIndexInformer
- type ChannelInformer
- type DecoratorInformer
- type Interface
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewChannelInformer ¶
func NewChannelInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, indexers cache.Indexers) cache.SharedIndexInformer
NewChannelInformer constructs a new informer for Channel type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
func NewDecoratorInformer ¶ added in v0.8.1
func NewDecoratorInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, indexers cache.Indexers) cache.SharedIndexInformer
NewDecoratorInformer constructs a new informer for Decorator type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
func NewFilteredChannelInformer ¶
func NewFilteredChannelInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, indexers cache.Indexers, tweakListOptions internalinterfaces.TweakListOptionsFunc) cache.SharedIndexInformer
NewFilteredChannelInformer constructs a new informer for Channel type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
func NewFilteredDecoratorInformer ¶ added in v0.8.1
func NewFilteredDecoratorInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, indexers cache.Indexers, tweakListOptions internalinterfaces.TweakListOptionsFunc) cache.SharedIndexInformer
NewFilteredDecoratorInformer constructs a new informer for Decorator type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
Types ¶
type ChannelInformer ¶
type ChannelInformer interface {
Informer() cache.SharedIndexInformer
Lister() v1alpha1.ChannelLister
}
ChannelInformer provides access to a shared informer and lister for Channels.
type DecoratorInformer ¶ added in v0.8.1
type DecoratorInformer interface {
Informer() cache.SharedIndexInformer
Lister() v1alpha1.DecoratorLister
}
DecoratorInformer provides access to a shared informer and lister for Decorators.
type Interface ¶
type Interface interface {
// Channels returns a ChannelInformer.
Channels() ChannelInformer
// Decorators returns a DecoratorInformer.
Decorators() DecoratorInformer
}
Interface provides access to all the informers in this group version.
func New ¶
func New(f internalinterfaces.SharedInformerFactory, namespace string, tweakListOptions internalinterfaces.TweakListOptionsFunc) Interface
New returns a new Interface.