Documentation
¶
Index ¶
- func NewEventPolicyBindingInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, ...) cache.SharedIndexInformer
- func NewEventPolicyInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, ...) cache.SharedIndexInformer
- func NewFilteredEventPolicyBindingInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, ...) cache.SharedIndexInformer
- func NewFilteredEventPolicyInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, ...) cache.SharedIndexInformer
- func NewFilteredHTTPPolicyBindingInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, ...) cache.SharedIndexInformer
- func NewFilteredHTTPPolicyInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, ...) cache.SharedIndexInformer
- func NewHTTPPolicyBindingInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, ...) cache.SharedIndexInformer
- func NewHTTPPolicyInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, ...) cache.SharedIndexInformer
- type EventPolicyBindingInformer
- type EventPolicyInformer
- type HTTPPolicyBindingInformer
- type HTTPPolicyInformer
- type Interface
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewEventPolicyBindingInformer ¶
func NewEventPolicyBindingInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, indexers cache.Indexers) cache.SharedIndexInformer
NewEventPolicyBindingInformer constructs a new informer for EventPolicyBinding type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
func NewEventPolicyInformer ¶
func NewEventPolicyInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, indexers cache.Indexers) cache.SharedIndexInformer
NewEventPolicyInformer constructs a new informer for EventPolicy type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
func NewFilteredEventPolicyBindingInformer ¶
func NewFilteredEventPolicyBindingInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, indexers cache.Indexers, tweakListOptions internalinterfaces.TweakListOptionsFunc) cache.SharedIndexInformer
NewFilteredEventPolicyBindingInformer constructs a new informer for EventPolicyBinding type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
func NewFilteredEventPolicyInformer ¶
func NewFilteredEventPolicyInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, indexers cache.Indexers, tweakListOptions internalinterfaces.TweakListOptionsFunc) cache.SharedIndexInformer
NewFilteredEventPolicyInformer constructs a new informer for EventPolicy type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
func NewFilteredHTTPPolicyBindingInformer ¶
func NewFilteredHTTPPolicyBindingInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, indexers cache.Indexers, tweakListOptions internalinterfaces.TweakListOptionsFunc) cache.SharedIndexInformer
NewFilteredHTTPPolicyBindingInformer constructs a new informer for HTTPPolicyBinding type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
func NewFilteredHTTPPolicyInformer ¶
func NewFilteredHTTPPolicyInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, indexers cache.Indexers, tweakListOptions internalinterfaces.TweakListOptionsFunc) cache.SharedIndexInformer
NewFilteredHTTPPolicyInformer constructs a new informer for HTTPPolicy type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
func NewHTTPPolicyBindingInformer ¶
func NewHTTPPolicyBindingInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, indexers cache.Indexers) cache.SharedIndexInformer
NewHTTPPolicyBindingInformer constructs a new informer for HTTPPolicyBinding type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
func NewHTTPPolicyInformer ¶
func NewHTTPPolicyInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, indexers cache.Indexers) cache.SharedIndexInformer
NewHTTPPolicyInformer constructs a new informer for HTTPPolicy type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
Types ¶
type EventPolicyBindingInformer ¶
type EventPolicyBindingInformer interface {
Informer() cache.SharedIndexInformer
Lister() v1alpha1.EventPolicyBindingLister
}
EventPolicyBindingInformer provides access to a shared informer and lister for EventPolicyBindings.
type EventPolicyInformer ¶
type EventPolicyInformer interface {
Informer() cache.SharedIndexInformer
Lister() v1alpha1.EventPolicyLister
}
EventPolicyInformer provides access to a shared informer and lister for EventPolicies.
type HTTPPolicyBindingInformer ¶
type HTTPPolicyBindingInformer interface {
Informer() cache.SharedIndexInformer
Lister() v1alpha1.HTTPPolicyBindingLister
}
HTTPPolicyBindingInformer provides access to a shared informer and lister for HTTPPolicyBindings.
type HTTPPolicyInformer ¶
type HTTPPolicyInformer interface {
Informer() cache.SharedIndexInformer
Lister() v1alpha1.HTTPPolicyLister
}
HTTPPolicyInformer provides access to a shared informer and lister for HTTPPolicies.
type Interface ¶
type Interface interface {
// EventPolicies returns a EventPolicyInformer.
EventPolicies() EventPolicyInformer
// EventPolicyBindings returns a EventPolicyBindingInformer.
EventPolicyBindings() EventPolicyBindingInformer
// HTTPPolicies returns a HTTPPolicyInformer.
HTTPPolicies() HTTPPolicyInformer
// HTTPPolicyBindings returns a HTTPPolicyBindingInformer.
HTTPPolicyBindings() HTTPPolicyBindingInformer
}
Interface provides access to all the informers in this group version.
func New ¶
func New(f internalinterfaces.SharedInformerFactory, namespace string, tweakListOptions internalinterfaces.TweakListOptionsFunc) Interface
New returns a new Interface.