Documentation
¶
Index ¶
- func NewAuthorizationPolicyInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, ...) cache.SharedIndexInformer
- func NewFilteredAuthorizationPolicyInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, ...) cache.SharedIndexInformer
- func NewFilteredPeerAuthenticationInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, ...) cache.SharedIndexInformer
- func NewFilteredRequestAuthenticationInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, ...) cache.SharedIndexInformer
- func NewPeerAuthenticationInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, ...) cache.SharedIndexInformer
- func NewRequestAuthenticationInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, ...) cache.SharedIndexInformer
- type AuthorizationPolicyInformer
- type Interface
- type PeerAuthenticationInformer
- type RequestAuthenticationInformer
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewAuthorizationPolicyInformer ¶
func NewAuthorizationPolicyInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, indexers cache.Indexers) cache.SharedIndexInformer
NewAuthorizationPolicyInformer constructs a new informer for AuthorizationPolicy type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
func NewFilteredAuthorizationPolicyInformer ¶
func NewFilteredAuthorizationPolicyInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, indexers cache.Indexers, tweakListOptions internalinterfaces.TweakListOptionsFunc) cache.SharedIndexInformer
NewFilteredAuthorizationPolicyInformer constructs a new informer for AuthorizationPolicy type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
func NewFilteredPeerAuthenticationInformer ¶
func NewFilteredPeerAuthenticationInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, indexers cache.Indexers, tweakListOptions internalinterfaces.TweakListOptionsFunc) cache.SharedIndexInformer
NewFilteredPeerAuthenticationInformer constructs a new informer for PeerAuthentication type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
func NewFilteredRequestAuthenticationInformer ¶
func NewFilteredRequestAuthenticationInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, indexers cache.Indexers, tweakListOptions internalinterfaces.TweakListOptionsFunc) cache.SharedIndexInformer
NewFilteredRequestAuthenticationInformer constructs a new informer for RequestAuthentication type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
func NewPeerAuthenticationInformer ¶
func NewPeerAuthenticationInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, indexers cache.Indexers) cache.SharedIndexInformer
NewPeerAuthenticationInformer constructs a new informer for PeerAuthentication type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
func NewRequestAuthenticationInformer ¶
func NewRequestAuthenticationInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, indexers cache.Indexers) cache.SharedIndexInformer
NewRequestAuthenticationInformer constructs a new informer for RequestAuthentication type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
Types ¶
type AuthorizationPolicyInformer ¶
type AuthorizationPolicyInformer interface {
Informer() cache.SharedIndexInformer
Lister() v1beta1.AuthorizationPolicyLister
}
AuthorizationPolicyInformer provides access to a shared informer and lister for AuthorizationPolicies.
type Interface ¶
type Interface interface {
// AuthorizationPolicies returns a AuthorizationPolicyInformer.
AuthorizationPolicies() AuthorizationPolicyInformer
// PeerAuthentications returns a PeerAuthenticationInformer.
PeerAuthentications() PeerAuthenticationInformer
// RequestAuthentications returns a RequestAuthenticationInformer.
RequestAuthentications() RequestAuthenticationInformer
}
Interface provides access to all the informers in this group version.
func New ¶
func New(f internalinterfaces.SharedInformerFactory, namespace string, tweakListOptions internalinterfaces.TweakListOptionsFunc) Interface
New returns a new Interface.
type PeerAuthenticationInformer ¶
type PeerAuthenticationInformer interface {
Informer() cache.SharedIndexInformer
Lister() v1beta1.PeerAuthenticationLister
}
PeerAuthenticationInformer provides access to a shared informer and lister for PeerAuthentications.
type RequestAuthenticationInformer ¶
type RequestAuthenticationInformer interface {
Informer() cache.SharedIndexInformer
Lister() v1beta1.RequestAuthenticationLister
}
RequestAuthenticationInformer provides access to a shared informer and lister for RequestAuthentications.