Documentation
¶
Index ¶
- type AuthorizationPolicyLister
- type AuthorizationPolicyListerExpansion
- type AuthorizationPolicyNamespaceLister
- type AuthorizationPolicyNamespaceListerExpansion
- type PeerAuthenticationLister
- type PeerAuthenticationListerExpansion
- type PeerAuthenticationNamespaceLister
- type PeerAuthenticationNamespaceListerExpansion
- type RequestAuthenticationLister
- type RequestAuthenticationListerExpansion
- type RequestAuthenticationNamespaceLister
- type RequestAuthenticationNamespaceListerExpansion
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type AuthorizationPolicyLister ¶
type AuthorizationPolicyLister interface {
// List lists all AuthorizationPolicies in the indexer.
List(selector labels.Selector) (ret []*v1beta1.AuthorizationPolicy, err error)
// AuthorizationPolicies returns an object that can list and get AuthorizationPolicies.
AuthorizationPolicies(namespace string) AuthorizationPolicyNamespaceLister
AuthorizationPolicyListerExpansion
}
AuthorizationPolicyLister helps list AuthorizationPolicies.
func NewAuthorizationPolicyLister ¶
func NewAuthorizationPolicyLister(indexer cache.Indexer) AuthorizationPolicyLister
NewAuthorizationPolicyLister returns a new AuthorizationPolicyLister.
type AuthorizationPolicyListerExpansion ¶
type AuthorizationPolicyListerExpansion interface{}
AuthorizationPolicyListerExpansion allows custom methods to be added to AuthorizationPolicyLister.
type AuthorizationPolicyNamespaceLister ¶
type AuthorizationPolicyNamespaceLister interface {
// List lists all AuthorizationPolicies in the indexer for a given namespace.
List(selector labels.Selector) (ret []*v1beta1.AuthorizationPolicy, err error)
// Get retrieves the AuthorizationPolicy from the indexer for a given namespace and name.
Get(name string) (*v1beta1.AuthorizationPolicy, error)
AuthorizationPolicyNamespaceListerExpansion
}
AuthorizationPolicyNamespaceLister helps list and get AuthorizationPolicies.
type AuthorizationPolicyNamespaceListerExpansion ¶
type AuthorizationPolicyNamespaceListerExpansion interface{}
AuthorizationPolicyNamespaceListerExpansion allows custom methods to be added to AuthorizationPolicyNamespaceLister.
type PeerAuthenticationLister ¶
type PeerAuthenticationLister interface {
// List lists all PeerAuthentications in the indexer.
List(selector labels.Selector) (ret []*v1beta1.PeerAuthentication, err error)
// PeerAuthentications returns an object that can list and get PeerAuthentications.
PeerAuthentications(namespace string) PeerAuthenticationNamespaceLister
PeerAuthenticationListerExpansion
}
PeerAuthenticationLister helps list PeerAuthentications.
func NewPeerAuthenticationLister ¶
func NewPeerAuthenticationLister(indexer cache.Indexer) PeerAuthenticationLister
NewPeerAuthenticationLister returns a new PeerAuthenticationLister.
type PeerAuthenticationListerExpansion ¶
type PeerAuthenticationListerExpansion interface{}
PeerAuthenticationListerExpansion allows custom methods to be added to PeerAuthenticationLister.
type PeerAuthenticationNamespaceLister ¶
type PeerAuthenticationNamespaceLister interface {
// List lists all PeerAuthentications in the indexer for a given namespace.
List(selector labels.Selector) (ret []*v1beta1.PeerAuthentication, err error)
// Get retrieves the PeerAuthentication from the indexer for a given namespace and name.
Get(name string) (*v1beta1.PeerAuthentication, error)
PeerAuthenticationNamespaceListerExpansion
}
PeerAuthenticationNamespaceLister helps list and get PeerAuthentications.
type PeerAuthenticationNamespaceListerExpansion ¶
type PeerAuthenticationNamespaceListerExpansion interface{}
PeerAuthenticationNamespaceListerExpansion allows custom methods to be added to PeerAuthenticationNamespaceLister.
type RequestAuthenticationLister ¶
type RequestAuthenticationLister interface {
// List lists all RequestAuthentications in the indexer.
List(selector labels.Selector) (ret []*v1beta1.RequestAuthentication, err error)
// RequestAuthentications returns an object that can list and get RequestAuthentications.
RequestAuthentications(namespace string) RequestAuthenticationNamespaceLister
RequestAuthenticationListerExpansion
}
RequestAuthenticationLister helps list RequestAuthentications.
func NewRequestAuthenticationLister ¶
func NewRequestAuthenticationLister(indexer cache.Indexer) RequestAuthenticationLister
NewRequestAuthenticationLister returns a new RequestAuthenticationLister.
type RequestAuthenticationListerExpansion ¶
type RequestAuthenticationListerExpansion interface{}
RequestAuthenticationListerExpansion allows custom methods to be added to RequestAuthenticationLister.
type RequestAuthenticationNamespaceLister ¶
type RequestAuthenticationNamespaceLister interface {
// List lists all RequestAuthentications in the indexer for a given namespace.
List(selector labels.Selector) (ret []*v1beta1.RequestAuthentication, err error)
// Get retrieves the RequestAuthentication from the indexer for a given namespace and name.
Get(name string) (*v1beta1.RequestAuthentication, error)
RequestAuthenticationNamespaceListerExpansion
}
RequestAuthenticationNamespaceLister helps list and get RequestAuthentications.
type RequestAuthenticationNamespaceListerExpansion ¶
type RequestAuthenticationNamespaceListerExpansion interface{}
RequestAuthenticationNamespaceListerExpansion allows custom methods to be added to RequestAuthenticationNamespaceLister.