Documentation
¶
Index ¶
- type PubSubLister
- type PubSubListerExpansion
- type PubSubNamespaceLister
- type PubSubNamespaceListerExpansion
- type SchedulerLister
- type SchedulerListerExpansion
- type SchedulerNamespaceLister
- type SchedulerNamespaceListerExpansion
- type StorageLister
- type StorageListerExpansion
- type StorageNamespaceLister
- type StorageNamespaceListerExpansion
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type PubSubLister ¶ added in v0.10.0
type PubSubLister interface {
// List lists all PubSubs in the indexer.
List(selector labels.Selector) (ret []*v1alpha1.PubSub, err error)
// PubSubs returns an object that can list and get PubSubs.
PubSubs(namespace string) PubSubNamespaceLister
PubSubListerExpansion
}
PubSubLister helps list PubSubs.
func NewPubSubLister ¶ added in v0.10.0
func NewPubSubLister(indexer cache.Indexer) PubSubLister
NewPubSubLister returns a new PubSubLister.
type PubSubListerExpansion ¶ added in v0.10.0
type PubSubListerExpansion interface{}
PubSubListerExpansion allows custom methods to be added to PubSubLister.
type PubSubNamespaceLister ¶ added in v0.10.0
type PubSubNamespaceLister interface {
// List lists all PubSubs in the indexer for a given namespace.
List(selector labels.Selector) (ret []*v1alpha1.PubSub, err error)
// Get retrieves the PubSub from the indexer for a given namespace and name.
Get(name string) (*v1alpha1.PubSub, error)
PubSubNamespaceListerExpansion
}
PubSubNamespaceLister helps list and get PubSubs.
type PubSubNamespaceListerExpansion ¶ added in v0.10.0
type PubSubNamespaceListerExpansion interface{}
PubSubNamespaceListerExpansion allows custom methods to be added to PubSubNamespaceLister.
type SchedulerLister ¶ added in v0.9.0
type SchedulerLister interface {
// List lists all Schedulers in the indexer.
List(selector labels.Selector) (ret []*v1alpha1.Scheduler, err error)
// Schedulers returns an object that can list and get Schedulers.
Schedulers(namespace string) SchedulerNamespaceLister
SchedulerListerExpansion
}
SchedulerLister helps list Schedulers.
func NewSchedulerLister ¶ added in v0.9.0
func NewSchedulerLister(indexer cache.Indexer) SchedulerLister
NewSchedulerLister returns a new SchedulerLister.
type SchedulerListerExpansion ¶ added in v0.9.0
type SchedulerListerExpansion interface{}
SchedulerListerExpansion allows custom methods to be added to SchedulerLister.
type SchedulerNamespaceLister ¶ added in v0.9.0
type SchedulerNamespaceLister interface {
// List lists all Schedulers in the indexer for a given namespace.
List(selector labels.Selector) (ret []*v1alpha1.Scheduler, err error)
// Get retrieves the Scheduler from the indexer for a given namespace and name.
Get(name string) (*v1alpha1.Scheduler, error)
SchedulerNamespaceListerExpansion
}
SchedulerNamespaceLister helps list and get Schedulers.
type SchedulerNamespaceListerExpansion ¶ added in v0.9.0
type SchedulerNamespaceListerExpansion interface{}
SchedulerNamespaceListerExpansion allows custom methods to be added to SchedulerNamespaceLister.
type StorageLister ¶ added in v0.8.1
type StorageLister interface {
// List lists all Storages in the indexer.
List(selector labels.Selector) (ret []*v1alpha1.Storage, err error)
// Storages returns an object that can list and get Storages.
Storages(namespace string) StorageNamespaceLister
StorageListerExpansion
}
StorageLister helps list Storages.
func NewStorageLister ¶ added in v0.8.1
func NewStorageLister(indexer cache.Indexer) StorageLister
NewStorageLister returns a new StorageLister.
type StorageListerExpansion ¶ added in v0.8.1
type StorageListerExpansion interface{}
StorageListerExpansion allows custom methods to be added to StorageLister.
type StorageNamespaceLister ¶ added in v0.8.1
type StorageNamespaceLister interface {
// List lists all Storages in the indexer for a given namespace.
List(selector labels.Selector) (ret []*v1alpha1.Storage, err error)
// Get retrieves the Storage from the indexer for a given namespace and name.
Get(name string) (*v1alpha1.Storage, error)
StorageNamespaceListerExpansion
}
StorageNamespaceLister helps list and get Storages.
type StorageNamespaceListerExpansion ¶ added in v0.8.1
type StorageNamespaceListerExpansion interface{}
StorageNamespaceListerExpansion allows custom methods to be added to StorageNamespaceLister.