Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type BrokerCellLister ¶
type BrokerCellLister interface {
// List lists all BrokerCells in the indexer.
List(selector labels.Selector) (ret []*v1alpha1.BrokerCell, err error)
// BrokerCells returns an object that can list and get BrokerCells.
BrokerCells(namespace string) BrokerCellNamespaceLister
BrokerCellListerExpansion
}
BrokerCellLister helps list BrokerCells.
func NewBrokerCellLister ¶
func NewBrokerCellLister(indexer cache.Indexer) BrokerCellLister
NewBrokerCellLister returns a new BrokerCellLister.
type BrokerCellListerExpansion ¶
type BrokerCellListerExpansion interface{}
BrokerCellListerExpansion allows custom methods to be added to BrokerCellLister.
type BrokerCellNamespaceLister ¶
type BrokerCellNamespaceLister interface {
// List lists all BrokerCells in the indexer for a given namespace.
List(selector labels.Selector) (ret []*v1alpha1.BrokerCell, err error)
// Get retrieves the BrokerCell from the indexer for a given namespace and name.
Get(name string) (*v1alpha1.BrokerCell, error)
BrokerCellNamespaceListerExpansion
}
BrokerCellNamespaceLister helps list and get BrokerCells.
type BrokerCellNamespaceListerExpansion ¶
type BrokerCellNamespaceListerExpansion interface{}
BrokerCellNamespaceListerExpansion allows custom methods to be added to BrokerCellNamespaceLister.
Click to show internal directories.
Click to hide internal directories.