Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type PullSubscriptionLister ¶
type PullSubscriptionLister interface {
// List lists all PullSubscriptions in the indexer.
List(selector labels.Selector) (ret []*v1beta1.PullSubscription, err error)
// PullSubscriptions returns an object that can list and get PullSubscriptions.
PullSubscriptions(namespace string) PullSubscriptionNamespaceLister
PullSubscriptionListerExpansion
}
PullSubscriptionLister helps list PullSubscriptions.
func NewPullSubscriptionLister ¶
func NewPullSubscriptionLister(indexer cache.Indexer) PullSubscriptionLister
NewPullSubscriptionLister returns a new PullSubscriptionLister.
type PullSubscriptionListerExpansion ¶
type PullSubscriptionListerExpansion interface{}
PullSubscriptionListerExpansion allows custom methods to be added to PullSubscriptionLister.
type PullSubscriptionNamespaceLister ¶
type PullSubscriptionNamespaceLister interface {
// List lists all PullSubscriptions in the indexer for a given namespace.
List(selector labels.Selector) (ret []*v1beta1.PullSubscription, err error)
// Get retrieves the PullSubscription from the indexer for a given namespace and name.
Get(name string) (*v1beta1.PullSubscription, error)
PullSubscriptionNamespaceListerExpansion
}
PullSubscriptionNamespaceLister helps list and get PullSubscriptions.
type PullSubscriptionNamespaceListerExpansion ¶
type PullSubscriptionNamespaceListerExpansion interface{}
PullSubscriptionNamespaceListerExpansion allows custom methods to be added to PullSubscriptionNamespaceLister.
type TopicLister ¶
type TopicLister interface {
// List lists all Topics in the indexer.
List(selector labels.Selector) (ret []*v1beta1.Topic, err error)
// Topics returns an object that can list and get Topics.
Topics(namespace string) TopicNamespaceLister
TopicListerExpansion
}
TopicLister helps list Topics.
func NewTopicLister ¶
func NewTopicLister(indexer cache.Indexer) TopicLister
NewTopicLister returns a new TopicLister.
type TopicListerExpansion ¶
type TopicListerExpansion interface{}
TopicListerExpansion allows custom methods to be added to TopicLister.
type TopicNamespaceLister ¶
type TopicNamespaceLister interface {
// List lists all Topics in the indexer for a given namespace.
List(selector labels.Selector) (ret []*v1beta1.Topic, err error)
// Get retrieves the Topic from the indexer for a given namespace and name.
Get(name string) (*v1beta1.Topic, error)
TopicNamespaceListerExpansion
}
TopicNamespaceLister helps list and get Topics.
type TopicNamespaceListerExpansion ¶
type TopicNamespaceListerExpansion interface{}
TopicNamespaceListerExpansion allows custom methods to be added to TopicNamespaceLister.