Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func DomainToURL ¶
DomainToURL converts a domain into an HTTP URL.
func GetClusterDomainName ¶
func GetClusterDomainName() string
GetClusterDomainName returns cluster's domain name or an error Closes issue: https://github.com/knative/eventing/issues/714
func GetSinkURI ¶
func GetSinkURI(ctx context.Context, dynamicClient dynamic.Interface, sink *corev1.ObjectReference, namespace string) (string, error)
GetSinkURI retrieves the sink URI from the object referenced by the given ObjectReference.
func ServiceHostName ¶
ServiceHostName creates the hostname for a Kubernetes Service.
func ToDNS1123Subdomain ¶
Converts 'name' to a valid DNS1123 subdomain, required for object names in K8s.
Types ¶
type PubSubable ¶ added in v0.9.0
type PubSubable interface {
kmeta.OwnerRefable
// PubSubSpec returns the PubSubSpec portion of the Spec.
PubSubSpec() *duckv1alpha1.PubSubSpec
// PubSubStatus returns the PubSubStatus portion of the Status.
PubSubStatus() *duckv1alpha1.PubSubStatus
// ConditionSet returns the apis.ConditionSet of the embedding object
// This Set must have the following Conditions defined in it.
// "TopicReady",
// "PullSubscriptionReady",
// Which will be set appropriately automagically by the pubsub_reconciler.go
ConditionSet() *apis.ConditionSet
}
PubSubable is an interface that each duckv1alpha1.PubSub duck type must support in order to get reconciled properly in a generic way.
Click to show internal directories.
Click to hide internal directories.