Documentation
¶
Overview ¶
Package iam provides interfaces and wrappers around the google iam client.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Client ¶
type Client interface {
// InstanceAttributeValue returns the value of the provided VM instance attribute.
// See https://godoc.org/cloud.google.com/compute/metadata#Client.ProjectID
InstanceAttributeValue(attr string) (string, error)
// ProjectID returns the current instance's project ID string.
// See https://godoc.org/cloud.google.com/compute/metadata#Client.InstanceAttributeValue
ProjectID() (string, error)
// OnGCE reports whether this process is running on Google Compute Engine.
// See https://godoc.org/cloud.google.com/compute/metadata#OnGCE
OnGCE() bool
}
Client matches the interface exposed by metadata.Client
func NewDefaultMetadataClient ¶
func NewDefaultMetadataClient() Client
func NewMetadataClient ¶
Click to show internal directories.
Click to hide internal directories.