Documentation
¶
Index ¶
- type BrokerCellLister
- type BrokerCellListerExpansion
- type BrokerCellNamespaceLister
- type BrokerCellNamespaceListerExpansion
- type PullSubscriptionLister
- type PullSubscriptionListerExpansion
- type PullSubscriptionNamespaceLister
- type PullSubscriptionNamespaceListerExpansion
- type TopicLister
- type TopicListerExpansion
- type TopicNamespaceLister
- type TopicNamespaceListerExpansion
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type BrokerCellLister ¶
type BrokerCellLister interface {
// List lists all BrokerCells in the indexer.
List(selector labels.Selector) (ret []*v1alpha1.BrokerCell, err error)
// BrokerCells returns an object that can list and get BrokerCells.
BrokerCells(namespace string) BrokerCellNamespaceLister
BrokerCellListerExpansion
}
BrokerCellLister helps list BrokerCells.
func NewBrokerCellLister ¶
func NewBrokerCellLister(indexer cache.Indexer) BrokerCellLister
NewBrokerCellLister returns a new BrokerCellLister.
type BrokerCellListerExpansion ¶
type BrokerCellListerExpansion interface{}
BrokerCellListerExpansion allows custom methods to be added to BrokerCellLister.
type BrokerCellNamespaceLister ¶
type BrokerCellNamespaceLister interface {
// List lists all BrokerCells in the indexer for a given namespace.
List(selector labels.Selector) (ret []*v1alpha1.BrokerCell, err error)
// Get retrieves the BrokerCell from the indexer for a given namespace and name.
Get(name string) (*v1alpha1.BrokerCell, error)
BrokerCellNamespaceListerExpansion
}
BrokerCellNamespaceLister helps list and get BrokerCells.
type BrokerCellNamespaceListerExpansion ¶
type BrokerCellNamespaceListerExpansion interface{}
BrokerCellNamespaceListerExpansion allows custom methods to be added to BrokerCellNamespaceLister.
type PullSubscriptionLister ¶
type PullSubscriptionLister interface {
// List lists all PullSubscriptions in the indexer.
List(selector labels.Selector) (ret []*v1alpha1.PullSubscription, err error)
// PullSubscriptions returns an object that can list and get PullSubscriptions.
PullSubscriptions(namespace string) PullSubscriptionNamespaceLister
PullSubscriptionListerExpansion
}
PullSubscriptionLister helps list PullSubscriptions.
func NewPullSubscriptionLister ¶
func NewPullSubscriptionLister(indexer cache.Indexer) PullSubscriptionLister
NewPullSubscriptionLister returns a new PullSubscriptionLister.
type PullSubscriptionListerExpansion ¶
type PullSubscriptionListerExpansion interface{}
PullSubscriptionListerExpansion allows custom methods to be added to PullSubscriptionLister.
type PullSubscriptionNamespaceLister ¶
type PullSubscriptionNamespaceLister interface {
// List lists all PullSubscriptions in the indexer for a given namespace.
List(selector labels.Selector) (ret []*v1alpha1.PullSubscription, err error)
// Get retrieves the PullSubscription from the indexer for a given namespace and name.
Get(name string) (*v1alpha1.PullSubscription, error)
PullSubscriptionNamespaceListerExpansion
}
PullSubscriptionNamespaceLister helps list and get PullSubscriptions.
type PullSubscriptionNamespaceListerExpansion ¶
type PullSubscriptionNamespaceListerExpansion interface{}
PullSubscriptionNamespaceListerExpansion allows custom methods to be added to PullSubscriptionNamespaceLister.
type TopicLister ¶
type TopicLister interface {
// List lists all Topics in the indexer.
List(selector labels.Selector) (ret []*v1alpha1.Topic, err error)
// Topics returns an object that can list and get Topics.
Topics(namespace string) TopicNamespaceLister
TopicListerExpansion
}
TopicLister helps list Topics.
func NewTopicLister ¶
func NewTopicLister(indexer cache.Indexer) TopicLister
NewTopicLister returns a new TopicLister.
type TopicListerExpansion ¶
type TopicListerExpansion interface{}
TopicListerExpansion allows custom methods to be added to TopicLister.
type TopicNamespaceLister ¶
type TopicNamespaceLister interface {
// List lists all Topics in the indexer for a given namespace.
List(selector labels.Selector) (ret []*v1alpha1.Topic, err error)
// Get retrieves the Topic from the indexer for a given namespace and name.
Get(name string) (*v1alpha1.Topic, error)
TopicNamespaceListerExpansion
}
TopicNamespaceLister helps list and get Topics.
type TopicNamespaceListerExpansion ¶
type TopicNamespaceListerExpansion interface{}
TopicNamespaceListerExpansion allows custom methods to be added to TopicNamespaceLister.